@@ -610,23 +610,21 @@ public interface MethodDescription extends TypeVariableSource,
          * {@inheritDoc}
          */
         public boolean isVisibleTo(TypeDescription typeDescription) {
-            return (isVirtual() || getDeclaringType().asErasure().isVisibleTo(typeDescription))
-                    && (isPublic()
-                    || typeDescription.equals(getDeclaringType().asErasure())
-                    || isProtected() && getDeclaringType().asErasure().isAssignableFrom(typeDescription)
-                    || !isPrivate() && typeDescription.isSamePackage(getDeclaringType().asErasure())
-                    || isPrivate() && typeDescription.isNestMateOf(getDeclaringType().asErasure()));
+            return getDeclaringType().asErasure().equals(typeDescription)
+                    || isPublic() && getDeclaringType().isPublic()
+                    || (isPublic() || isProtected()) && getDeclaringType().asErasure().isAssignableFrom(typeDescription)
+                    || !isPrivate() && getDeclaringType().asErasure().isSamePackage(typeDescription)
+                    || isPrivate() && getDeclaringType().asErasure().isNestMateOf(typeDescription);
         }
 
         /**
          * {@inheritDoc}
          */
         public boolean isAccessibleTo(TypeDescription typeDescription) {
-            return (isVirtual() || getDeclaringType().asErasure().isVisibleTo(typeDescription))
-                    && (isPublic()
-                    || typeDescription.equals(getDeclaringType().asErasure())
-                    || !isPrivate() && typeDescription.isSamePackage(getDeclaringType().asErasure()))
-                    || isPrivate() && typeDescription.isNestMateOf(getDeclaringType().asErasure());
+            return getDeclaringType().asErasure().equals(typeDescription)
+                    || isPublic() && getDeclaringType().isPublic()
+                    || !isPrivate() && getDeclaringType().asErasure().isSamePackage(typeDescription)
+                    || isPrivate() && getDeclaringType().asErasure().isNestMateOf(typeDescription);
         }
 
         /**
@@ -1049,7 +1047,7 @@ public interface MethodDescription extends TypeVariableSource,
                 stringBuilder.append(Modifier.toString(modifiers)).append(' ');
             }
             if (isMethod()) {
-                stringBuilder.append(getReturnType().asErasure().getActualName()).append(' ');
+                stringBuilder.append('?').append(' ');
                 stringBuilder.append(getDeclaringType().asErasure().getActualName()).append('.');
             }
             return stringBuilder.append(getName()).append("(?)").toString();
