@@ -35,6 +35,7 @@ import net.bytebuddy.matcher.ElementMatcher;
 import net.bytebuddy.utility.CompoundList;
 import net.bytebuddy.utility.JavaType;
 import net.bytebuddy.utility.nullability.MaybeNull;
+import org.objectweb.asm.Opcodes;
 
 import java.lang.annotation.ElementType;
 import java.util.*;
@@ -1699,6 +1700,8 @@ public interface InstrumentedType extends TypeDescription {
                     throw new IllegalStateException("Duplicate method signature for " + methodDescription);
                 } else if ((methodDescription.getModifiers() & ~ModifierContributor.ForMethod.MASK) != 0) {
                     throw new IllegalStateException("Illegal modifiers " + methodDescription.getModifiers() + " for " + methodDescription);
+                } else if (methodDescription.isAbstract() && (methodDescription.getModifiers() & Opcodes.ACC_STRICT) != 0) {
+                    throw new IllegalStateException("Cannot declare strict computations for " + methodDescription);
                 } else if (isInterface() && !methodDescription.isPublic() && !methodDescription.isPrivate()) {
                     throw new IllegalStateException("Methods declared by an interface must be public or private " + methodDescription);
                 }
@@ -1842,13 +1845,16 @@ public interface InstrumentedType extends TypeDescription {
          * @return {@code true} if the given identifier is valid.
          */
         private static boolean isValidIdentifier(String identifier) {
-            if (KEYWORDS.contains(identifier) || identifier.length() == 0 || !Character.isJavaIdentifierStart(identifier.charAt(0))) {
+            if (KEYWORDS.contains(identifier)
+                    || identifier.length() == 0
+                    || !(Character.isJavaIdentifierStart(identifier.charAt(0))
+                    || Character.isUnicodeIdentifierStart(identifier.charAt(0)))) {
                 return false;
             } else if (identifier.equals(PackageDescription.PACKAGE_CLASS_NAME)) {
                 return true;
             }
             for (int index = 1; index < identifier.length(); index++) {
-                if (!Character.isJavaIdentifierPart(identifier.charAt(index))) {
+                if (!(Character.isJavaIdentifierPart(identifier.charAt(index)) || Character.isUnicodeIdentifierPart(identifier.charAt(index)))) {
                     return false;
                 }
             }
