@@ -198,6 +198,20 @@ public class AdviceAssignReturnedTest {
         }
     }
 
+    @Test
+    public void testAssignReturnedToThrownSuppressScalar() throws Exception {
+        Class<?> type = new ByteBuddy()
+                .redefine(SampleThrowing.class)
+                .visit(Advice.withCustomMapping()
+                        .with(new Advice.AssignReturned.Factory())
+                        .to(ToThrownSuppressScalar.class)
+                        .on(named(BAR)))
+                .make()
+                .load(ClassLoadingStrategy.BOOTSTRAP_LOADER, ClassLoadingStrategy.Default.WRAPPER)
+                .getLoaded();
+        assertThat(type.getMethod(BAR).invoke(type.getConstructor().newInstance()), nullValue(Object.class));
+    }
+
     @Test(expected = RuntimeException.class)
     public void testAssignReturnedToThrownArray() throws Exception {
         Class<?> type = new ByteBuddy()
@@ -217,6 +231,20 @@ public class AdviceAssignReturnedTest {
         }
     }
 
+    @Test
+    public void testAssignReturnedToThrownSuppressedArray() throws Exception {
+        Class<?> type = new ByteBuddy()
+                .redefine(SampleThrowing.class)
+                .visit(Advice.withCustomMapping()
+                        .with(new Advice.AssignReturned.Factory())
+                        .to(ToThrownSuppressedArray.class)
+                        .on(named(BAR)))
+                .make()
+                .load(ClassLoadingStrategy.BOOTSTRAP_LOADER, ClassLoadingStrategy.Default.WRAPPER)
+                .getLoaded();
+        assertThat(type.getMethod(BAR).invoke(type.getConstructor().newInstance()), nullValue(Object.class));
+    }
+
     @Test
     public void testAssignReturnedToArgumentArrayAsScalar() throws Exception {
         Class<?> type = new ByteBuddy()
@@ -564,6 +592,10 @@ public class AdviceAssignReturnedTest {
         public String foo(String value) {
             throw new RuntimeException();
         }
+
+        public void bar() {
+            throw new RuntimeException();
+        }
     }
 
     public static class ToArgumentScalar {
@@ -780,6 +812,16 @@ public class AdviceAssignReturnedTest {
         }
     }
 
+    public static class ToThrownSuppressScalar {
+
+        @Advice.OnMethodExit(onThrowable = Throwable.class)
+        @Advice.AssignReturned.ToThrown
+        @Advice.AssignReturned.AsScalar(skipOnDefaultValue = false)
+        public static RuntimeException exit() {
+            return null;
+        }
+    }
+
     public static class ToThrownArray {
 
         @Advice.OnMethodExit(onThrowable = Throwable.class)
@@ -792,6 +834,15 @@ public class AdviceAssignReturnedTest {
         }
     }
 
+    public static class ToThrownSuppressedArray {
+
+        @Advice.OnMethodExit(onThrowable = Throwable.class)
+        @Advice.AssignReturned.ToThrown(index = 0)
+        public static Throwable[] exit() {
+            return new Throwable[1];
+        }
+    }
+
     public static class ToArgumentArrayAsScalar {
 
         @Advice.OnMethodEnter
