@@ -23,6 +23,7 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.MethodRule;
 import org.objectweb.asm.*;
+import org.objectweb.asm.signature.SignatureWriter;
 
 import java.io.Serializable;
 import java.lang.annotation.Annotation;
@@ -31,6 +32,7 @@ import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.reflect.Array;
 import java.lang.reflect.GenericSignatureFormatError;
+import java.lang.reflect.MalformedParameterizedTypeException;
 import java.util.*;
 import java.util.concurrent.Callable;
 
@@ -611,6 +613,32 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
         typeDescription.getDeclaredMethods().filter(isMethod()).getOnly().getReturnType().getSort();
     }
 
+    @Test(expected = IllegalStateException.class)
+    public void testMalformedTypeVariableDefinition() throws Exception {
+        TypeDescription typeDescription = describe(TypeVariableMalformer.malform(MalformedTypeVariable.class));
+        assertThat(typeDescription.getDeclaredFields().size(), is(1));
+        typeDescription.getDeclaredFields().getOnly().getType().getUpperBounds();
+    }
+
+    @Test(expected = IllegalStateException.class)
+    public void testMalformedParameterizedTypeVariableDefinition() throws Exception {
+        TypeDescription typeDescription = describe(TypeVariableMalformer.malform(MalformedParameterizedTypeVariable.class));
+        assertThat(typeDescription.getDeclaredFields().getOnly().getType().getTypeArguments().size(), is(1));
+        typeDescription.getDeclaredFields().getOnly().getType().getTypeArguments().getOnly().getUpperBounds();
+    }
+
+    @Test(expected = MalformedParameterizedTypeException.class)
+    public void testMalformedParameterizedLengthDefinitionArguments() throws Exception {
+        TypeDescription typeDescription = describe(ParameterizedTypeLengthMalformer.malform(MalformedParameterizedLength.class));
+        typeDescription.getDeclaredFields().getOnly().getType().getTypeArguments();
+    }
+
+    @Test(expected = MalformedParameterizedTypeException.class)
+    public void testMalformedParameterizedLengthDefinitionOwner() throws Exception {
+        TypeDescription typeDescription = describe(ParameterizedTypeLengthMalformer.malform(MalformedParameterizedLength.class));
+        typeDescription.getDeclaredFields().getOnly().getType().getOwnerType();
+    }
+
     @Test
     public void testRepresents() throws Exception {
         assertThat(describe(Object.class).represents(Object.class), is(true));
@@ -913,8 +941,6 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
 
     private static class SignatureMalformer extends ClassVisitor {
 
-        private static final String FOO = "foo";
-
         public SignatureMalformer(ClassVisitor classVisitor) {
             super(OpenedClassReader.ASM_API, classVisitor);
         }
@@ -935,8 +961,8 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
         }
 
         @Override
-        public FieldVisitor visitField(int access, String name, String desc, String signature, Object value) {
-            return super.visitField(access, name, desc, FOO, value);
+        public FieldVisitor visitField(int access, String name, String descriptor, String signature, Object value) {
+            return super.visitField(access, name, descriptor, FOO, value);
         }
 
         @Override
@@ -945,6 +971,78 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
         }
     }
 
+    private static class TypeVariableMalformer extends ClassVisitor {
+
+        public TypeVariableMalformer(ClassVisitor classVisitor) {
+            super(OpenedClassReader.ASM_API, classVisitor);
+        }
+
+        public static Class<?> malform(Class<?> type) throws Exception {
+            ClassReader classReader = new ClassReader(type.getName());
+            ClassWriter classWriter = new ClassWriter(classReader, 0);
+            classReader.accept(new TypeVariableMalformer(classWriter), 0);
+            ClassLoader classLoader = new ByteArrayClassLoader(ClassLoadingStrategy.BOOTSTRAP_LOADER,
+                    Collections.singletonMap(type.getName(), classWriter.toByteArray()),
+                    ByteArrayClassLoader.PersistenceHandler.MANIFEST);
+            return classLoader.loadClass(type.getName());
+        }
+
+        @Override
+        public FieldVisitor visitField(int access, String name, String descriptor, String signature, Object value) {
+            if (descriptor.equals(Type.getDescriptor(Object.class))) {
+                signature = "TA;";
+            } else if (descriptor.equals(Type.getDescriptor(Set.class))) {
+                signature = "L" + Type.getInternalName(Set.class) + "<TA;>;";
+            }
+            return super.visitField(access, name, descriptor, signature, value);
+        }
+
+        @Override
+        public void visitInnerClass(String name, String outerName, String innerName, int access) {
+            /* do nothing */
+        }
+
+        @Override
+        public void visitOuterClass(String owner, String name, String descriptor) {
+            /* do nothing */
+        }
+    }
+
+    private static class ParameterizedTypeLengthMalformer extends ClassVisitor {
+
+        public ParameterizedTypeLengthMalformer(ClassVisitor classVisitor) {
+            super(OpenedClassReader.ASM_API, classVisitor);
+        }
+
+        public static Class<?> malform(Class<?> type) throws Exception {
+            ClassReader classReader = new ClassReader(type.getName());
+            ClassWriter classWriter = new ClassWriter(classReader, 0);
+            classReader.accept(new ParameterizedTypeLengthMalformer(classWriter), 0);
+            ClassLoader classLoader = new ByteArrayClassLoader(ClassLoadingStrategy.BOOTSTRAP_LOADER,
+                    Collections.singletonMap(type.getName(), classWriter.toByteArray()),
+                    ByteArrayClassLoader.PersistenceHandler.MANIFEST);
+            return classLoader.loadClass(type.getName());
+        }
+
+        @Override
+        public FieldVisitor visitField(int access, String name, String descriptor, String signature, Object value) {
+            if (descriptor.equals(Type.getDescriptor(Map.class))) {
+                signature = "L" + Type.getInternalName(Map.class) + "<" + Type.getDescriptor(Object.class) + ">;";
+            }
+            return super.visitField(access, name, descriptor, signature, value);
+        }
+
+        @Override
+        public void visitInnerClass(String name, String outerName, String innerName, int access) {
+            /* do nothing */
+        }
+
+        @Override
+        public void visitOuterClass(String owner, String name, String descriptor) {
+            /* do nothing */
+        }
+    }
+
     @SuppressWarnings("unused")
     public abstract static class MalformedBase<T> implements Callable<T> {
 
@@ -953,6 +1051,24 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
         abstract Callable<T> foo();
     }
 
+    @SuppressWarnings("unused")
+    public abstract static class MalformedTypeVariable {
+
+        Object foo;
+    }
+
+    @SuppressWarnings("unused")
+    public abstract static class MalformedParameterizedTypeVariable {
+
+        Set<Object> foo;
+    }
+
+    @SuppressWarnings("unused")
+    public abstract static class MalformedParameterizedLength {
+
+        Map<Object, Object> foo;
+    }
+
     static class SamplePackagePrivate {
         /* empty */
     }
